/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 *  nfc-extension.c
 * 
 *  Copyright (C) 2006-2008 Brian Pepple
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Author: Brian Pepple <bpepple@fedoraproject.org>
 * 
 */

#ifdef HAVE_CONFIG_H
 #include <config.h> /* for GETTEXT_PACKAGE */
#endif

#include "nfc-extension.h"
#include "nfc-converter.h"

#include <libnautilus-extension/nautilus-menu-provider.h>

#include <glib/gi18n-lib.h>
#include <gtk/gtkicontheme.h>
#include <gtk/gtkwidget.h>

#include <string.h> /* For strcmp */

static void nfc_extension_instance_init (NfcExtension      *flac);
static void nfc_extension_class_init    (NfcExtensionClass *class);

static GType flac_converter_type = 0;

static gboolean
flac_converter_file_is_flac (NautilusFileInfo *file_info)
{
	gchar    *tmp;

	/* Is this a file? */
	tmp = nautilus_file_info_get_uri_scheme (file_info);
	if (strcmp (tmp, "file") != 0) {
		g_free (tmp);
		return FALSE;
	}
	g_free (tmp);

	/* Now lets get the mime type, and only convert flac files */
	tmp = nautilus_file_info_get_mime_type (file_info);
	if (strncmp (tmp, "audio/x-flac", 12) != 0) {
		g_free (tmp);
		return FALSE;
	}
	g_free (tmp);

	return TRUE;
}

static GList *
flac_converter_filter_flacs (GList *files)
{
	GList *flacs;
	GList *file;

	flacs = NULL;

	for (file = files; file != NULL; file = file->next) {
		if (flac_converter_file_is_flac (file->data))
			flacs = g_list_prepend (flacs, file->data);
	}

	return flacs;
}

static void
flac_convert_callback (NautilusMenuItem *item,
		       GList            *files)
{
	NfcConverter *converter = nfc_converter_new (flac_converter_filter_flacs (files));
	nfc_converter_show_dialog (converter);
}

static GList *
nfc_extension_get_background_items (NautilusMenuProvider  *provider,
				    GtkWidget             *window,
				    NautilusFileInfo      *file_info)
{
	return NULL;
}

GList *
nfc_extension_get_file_items (NautilusMenuProvider *provider,
			      GtkWidget            *window,
			      GList                *files)
{
	NautilusMenuItem *item;
	GList *file;
	GList *items = NULL;

	for (file = files; file != NULL; file = file->next) {
		if (flac_converter_file_is_flac (file->data)) {
			item = nautilus_menu_item_new ("NautilusFlacConverter::convert",
						       _("_Convert FLAC to Ogg..."),
						       _("Convert each selected FLAC to an Ogg"),
						       "stock_insert-sound-plugin");

			g_signal_connect (item, "activate",
					  G_CALLBACK (flac_convert_callback),
					  nautilus_file_info_list_copy (files));

			items = g_list_prepend (items, item);
			items = g_list_reverse (items);

			return items;
		}
	}

	return NULL;
}

static void
nfc_extension_menu_provider_iface_init (NautilusMenuProviderIface *iface)
{
	iface->get_background_items = nfc_extension_get_background_items;
	iface->get_file_items = nfc_extension_get_file_items;
}

static void
nfc_extension_instance_init (NfcExtension *flac)
{
}

static void
nfc_extension_class_init (NfcExtensionClass *class)
{
}

GType
nfc_extension_get_type (void)
{
	return flac_converter_type;
}

void
nfc_extension_register_type (GTypeModule *module)
{
	static const GTypeInfo info = {
		sizeof (NfcExtensionClass),
		(GBaseInitFunc) NULL,
		(GBaseFinalizeFunc) NULL,
		(GClassInitFunc) nfc_extension_class_init,
		NULL,
		NULL,
		sizeof (NfcExtension),
		0,
		(GInstanceInitFunc) nfc_extension_instance_init,
	};

	static const GInterfaceInfo menu_provider_iface_info = {
		(GInterfaceInitFunc) nfc_extension_menu_provider_iface_init,
		NULL,
		NULL,
	};

	flac_converter_type = g_type_module_register_type (module,
							   G_TYPE_OBJECT,
							   "NfcExtension",
							   &info, 0);

	g_type_module_add_interface (module,
				     flac_converter_type,
				     NAUTILUS_TYPE_MENU_PROVIDER,
				     &menu_provider_iface_info);
}
